%Function that estimate a initial solution with u0 and v0 parameters fixed.
% Toolbox created Carles Matabosch Gerones
% Universitat de Girona, Catalunya (Spain) March 2003
function [K,A]=initialsolution(r1,s1,U1,V1,r2,s2,U2,V2,r3,s3,U3,V3,u0,v0)
F{1}=U1*[r1 0 0;0 s1 0;0 0 0]*V1';
F{2}=U2*[r2 0 0;0 s2 0;0 0 0]*V2';
F{3}=U3*[r3 0 0;0 s3 0;0 0 0]*V3';
n_f=3; %number of fundamental matrix
vr(1)=r1;vr(2)=r2;vr(3)=r3;vs(1)=s1;vs(2)=s2;vs(3)=s3;
U{1}=U1;U{2}=U2;U{3}=U3;V{1}=V1;V{2}=V2;V{3}=V3;

j=0;
for i=1:n_f
u11=U{i}(1,1);u12=U{i}(1,2);
u21=U{i}(2,1);u22=U{i}(2,2);
u31=U{i}(3,1);u32=U{i}(3,2);
v11=V{i}(1,1);v12=V{i}(1,2);
v21=V{i}(2,1);v22=V{i}(2,2);
v31=V{i}(3,1);v32=V{i}(3,2);
r=vr(i);s=vs(i);
%Three parameters of matrix K are fixed because only depneds by u0 and v0
k2=u0*v0;
k3=u0;
k5=v0;
syms k1 k4  
%The following functions are the two equations of simplified Kruppa equations
f1=r^2*(k1*v11^2+2*k2*v11*v21+2*k3*v11*v31+k4*v21^2+2*k5*v31*v21+v31*v31)*(-1)*(k1*u11*u12+k2*(u22*u11+u12*u21)+k3*(u32*u11+u12*u31)+k4*u22*u21+k5*(u32*u21+u22*u31)+u32*u31)-r*s*(k1*v11*v12+k2*(v21*v12+v11*v22)+k3*(v31*v12+v11*v32)+k4*v21*v22+k5*(v31*v22+v21*v32)+v31*v32)*(k1*u12*u12+2*k2*u22*u12+2*k3*u12*u32+k4*u22*u22+2*k5*u32*u22+u32*u32);
f2=r^2*(k1*v11^2+2*k2*v11*v21+2*k3*v11*v31+k4*v21^2+2*k5*v31*v21+v31*v31)*(k1*u11*u11+2*k2*u11*u21+2*k3*u11*u31+k4*u21*u21+2*k5*u31*u21+u31*u31)-s^2*(k1*v12*v12+2*k2*v12*v22+2*k3*v12*v32+k4*v22*v22+2*k5*v32*v22+v32*v32)*(k1*u12*u12+2*k2*u22*u12+2*k3*u12*u32+k4*u22*u22+2*k5*u32*u22+u32*u32);
f1s=simplify(f1);
f2s=simplify(f2);
[vk1,vk4]=solve(f1s,f2s);
vk1=eval(vk1);
vk4=eval(vk4);  %vk1 and vk4 are all the solutions of equations f1 and f2
for val=1:length(vk1)
    err1=subs(f1,{k1,k4},{vk1(val),vk4(val)});
    err2=subs(f2,{k1,k4},{vk1(val),vk4(val)});
end    
%the foolowing bucle extract the real solution from all the possible ones
for k=1:length(vk1)
    if (abs(imag(vk1(k)))<0.00001 & abs(imag(vk4(k)))<0.00001 & vk1(k)<10^10 & vk4(k)<10^10 & vk1(k)>-10^10 & vk4(k)>-10^10)% & vk1(k)>0 & vk4(k)>0 & )
        j=j+1;
        k1r(j)=vk1(k);
        k4r(j)=vk4(k);
    end
end
end
%In order to find the best solution between all the real ones, we choose
%the solution which minimize the constraint of Huang-Faugeras
for i=1:length(k1r)
    Kr=[k1r(i) k2 k3;k2 k4r(i) k5;k3 k5 1];
    A=matrixA(Kr);
    Km=A*A';
    mA{i}=matrixA(Km);
    erra=(trace(mA{i}'*F{1}*mA{i}*mA{i}'*F{1}'*mA{i}))^2-2*trace((mA{i}'*F{1}*mA{i}*mA{i}'*F{1}'*mA{i})^2);
    errb=(trace(mA{i}'*F{2}*mA{i}*mA{i}'*F{2}'*mA{i}))^2-2*trace((mA{i}'*F{2}*mA{i}*mA{i}'*F{2}'*mA{i})^2);
    errc=(trace(mA{i}'*F{3}*mA{i}*mA{i}'*F{3}'*mA{i}))^2-2*trace((mA{i}'*F{3}*mA{i}*mA{i}'*F{3}'*mA{i})^2);
    err(i)=norm([erra errb errc]);
end
[val,in]=min(err);
A=mA{in};
K=A*A';
