%Minimization Function
%Where:
%jSF 3x20
    %Each row is a vector of 20 terms of svd decomposition of F
%Ki: 3x3 Initial K matrix
% Toolbox created Carles Matabosch Gerones
% Universitat de Girona, Catalunya (Spain) March 2003

function [Ahg,errorhf]=minimization(jSF,Ki)
[r,s,vU,vV,r2,s2,vU2,vV2,r3,s3,vU3,vV3]=descomSF(jSF);
F1=vU*[r 0 0;0 s 0;0 0 0]*vV';
F2=vU2*[r2 0 0;0 s2 0;0 0 0]*vV2';
F3=vU3*[r3 0 0;0 s3 0;0 0 0]*vV3';
U{1}=vU;
U{2}=vU2;
U{3}=vU3;
V{1}=vV;
V{2}=vV2;
V{3}=vV3;
vr(1)=r;
vr(2)=r2;
vr(3)=r3;
vs(1)=s;
vs(2)=s2;
vs(3)=s3;

k1=sym('k1','real');k2=sym('k2','real');k3=sym('k3','real');k4=sym('k4','real');k5=sym('k5','real');
n_f=3; %Number of Fundamental Matrix. Now is only available for 3.
for i=1:n_f
     u11=U{i}(1,1);
     u12=U{i}(1,2);
     u13=U{i}(1,3);
     u21=U{i}(2,1);u22=U{i}(2,2);u23=U{i}(2,3);
     u31=U{i}(3,1);u32=U{i}(3,2);u33=U{i}(3,3);
     v11=V{i}(1,1);v12=V{i}(1,2);v13=V{i}(1,3);v21=V{i}(2,1);v22=V{i}(2,2);v23=V{i}(2,3);v31=V{i}(3,1);v32=V{i}(3,2);v33=V{i}(3,3);
     r=vr(i);s=vs(i);
    f(1,i)=((r^2*v11*k1+r^2*v21*k2+r^2*v31*k3)*v11+(r^2*v11*k2+r^2*v21*k4+r^2*v31*k5)*v21+(r^2*v11*k3+r^2*v21*k5+r^2*v31)*v31)*(-(u12*k1+u22*k2+u32*k3)*u11-(u12*k2+u22*k4+u32*k5)*u21-(u12*k3+u22*k5+u32)*u31)-((u12*k1+u22*k2+u32*k3)*u12+(u12*k2+u22*k4+u32*k5)*u22+(u12*k3+u22*k5+u32)*u32)*((r*s*v11*k1+r*s*v21*k2+r*s*v31*k3)*v12+(r*s*v11*k2+r*s*v21*k4+r*s*v31*k5)*v22+(r*s*v11*k3+r*s*v21*k5+r*s*v31)*v32);
    f(1,n_f+i)=((r^2*v11*k1+r^2*v21*k2+r^2*v31*k3)*v11+(r^2*v11*k2+r^2*v21*k4+r^2*v31*k5)*v21+(r^2*v11*k3+r^2*v21*k5+r^2*v31)*v31)*((u11*k1+u21*k2+u31*k3)*u11+(u11*k2+u21*k4+u31*k5)*u21+(u11*k3+u21*k5+u31)*u31)-((u12*k1+u22*k2+u32*k3)*u12+(u12*k2+u22*k4+u32*k5)*u22+(u12*k3+u22*k5+u32)*u32)*((s^2*v12*k1+s^2*v22*k2+s^2*v32*k3)*v12+(s^2*v12*k2+s^2*v22*k4+s^2*v32*k5)*v22+(s^2*v12*k3+s^2*v22*k5+s^2*v32)*v32);     
end
% Computation of partial derivates of 6 symplified kruppa equations
for i=1:2*n_f
    df(1,i)=diff(f(1,i),k1);
    df(2,i)=diff(f(1,i),k2);
    df(3,i)=diff(f(1,i),k3);
    df(4,i)=diff(f(1,i),k4);
    df(5,i)=diff(f(1,i),k5);
end
% Computation of 2-partial derivates.
for i=1:5
    d2f1(i,1)=diff(df(i,1),k1);
    d2f1(i,2)=diff(df(i,1),k2);
    d2f1(i,3)=diff(df(i,1),k3);
    d2f1(i,4)=diff(df(i,1),k4);
    d2f1(i,5)=diff(df(i,1),k5);
    d2f2(i,1)=diff(df(i,2),k1);
    d2f2(i,2)=diff(df(i,2),k2);
    d2f2(i,3)=diff(df(i,2),k3);
    d2f2(i,4)=diff(df(i,2),k4);
    d2f2(i,5)=diff(df(i,2),k5);
    d2f3(i,1)=diff(df(i,3),k1);
    d2f3(i,2)=diff(df(i,3),k2);
    d2f3(i,3)=diff(df(i,3),k3);
    d2f3(i,4)=diff(df(i,3),k4);
    d2f3(i,5)=diff(df(i,3),k5);
    d2f4(i,1)=diff(df(i,4),k1);
    d2f4(i,2)=diff(df(i,4),k2);
    d2f4(i,3)=diff(df(i,4),k3);
    d2f4(i,4)=diff(df(i,4),k4);
    d2f4(i,5)=diff(df(i,4),k5);    
    d2f5(i,1)=diff(df(i,5),k1);
    d2f5(i,2)=diff(df(i,5),k2);
    d2f5(i,3)=diff(df(i,5),k3);
    d2f5(i,4)=diff(df(i,5),k4);
    d2f5(i,5)=diff(df(i,5),k5);    
    d2f6(i,1)=diff(df(i,6),k1);
    d2f6(i,2)=diff(df(i,6),k2);
    d2f6(i,3)=diff(df(i,6),k3);
    d2f6(i,4)=diff(df(i,6),k4);
    d2f6(i,5)=diff(df(i,6),k5);       
end
k1=Ki(1,1);k2=Ki(1,2);k3=Ki(1,3);k4=Ki(2,2);k5=Ki(2,3);
mk=[k1 k2 k3 k4 k5];
fc=k2-k3*k5;
% Restriction k2=k3xk5
dfc(1)=0;
dfc(2)=1;
dfc(3)=-k5;
dfc(4)=0;
dfc(5)=-k3;
itermax=50;
error(1)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(1)>0.00000000001 & error2>0.000001)
    H1=eval(d2f1);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H1 df2' df3' df4' df5' dfc';df2 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df1';f2;f3;f4;f5;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(1)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{1}=matrixA(K);
error(2)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(2)>0.00000000001 & error2>0.000001)
    H1=eval(d2f1);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H1 df2' df4' df5' df6' dfc';df2 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df1';f2;f4;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(2)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{2}=matrixA(K);
error(3)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(3)>0.00000000001 & error2>0.000001)
    H1=eval(d2f1);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H1 df2' df4' df5' df3' dfc';df2 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df3 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df1';f2;f4;f5;f3;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(3)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{3}=matrixA(K);

error(4)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(4)>0.00000000001 & error2>0.000001)
    H1=eval(d2f1);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H1 df2' df4' df3' df6' dfc';df2 0 0 0 0 0;df4 0 0 0 0 0;df3 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df1';f2;f4;f3;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(4)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{4}=matrixA(K);

error(5)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(5)>0.00000000001 & error2>0.000001)
    H1=eval(d2f1);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H1 df2' df3' df5' df6' dfc';df2 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df1';f2;f3;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(5)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{5}=matrixA(K);

error(6)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(6)>0.00000000001 & error2>0.000001)
    H1=eval(d2f1);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H1 df3' df4' df5' df6' dfc';df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df1';f3;f4;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(6)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{6}=matrixA(K);

error(7)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(7)>0.00000000001 & error2>0.000001)
    H2=eval(d2f2);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H2 df1' df3' df4' df5' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df2';f1;f3;f4;f5;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(7)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{7}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(8)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(8)>0.00000000001 & error2>0.000001)
    H2=eval(d2f2);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H2 df1' df4' df5' df6' dfc';df1 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df2';f1;f4;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(8)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{8}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(9)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(9)>0.00000000001 & error2>0.000001)
    H2=eval(d2f2);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H2 df1' df4' df5' df3' dfc';df1 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df3 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df2';f1;f4;f5;f3;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(9)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{9}=matrixA(K);
error(10)=1;
n=1;
M=[];
S=[];
error2=100;
mk=[k1 k2 k3 k4 k5];
while (n<=itermax & error(10)>0.00000000001 & error2>0.000001)
    H2=eval(d2f2);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H2 df1' df4' df3' df6' dfc';df1 0 0 0 0 0;df4 0 0 0 0 0;df3 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df2';f1;f4;f3;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(10)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{10}=matrixA(K);

error(11)=1;
n=1;
M=[];
mk=[k1 k2 k3 k4 k5];
S=[];
error2=100;
while (n<=itermax & error(11)>0.00000000001 & error2>0.000001)
    H2=eval(d2f2);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H2 df1' df3' df5' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df2';f1;f3;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(11)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{11}=matrixA(K);

error(12)=1;
mk=[k1 k2 k3 k4 k5];
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(12)>0.00000000001 & error2>0.000001)
    H2=eval(d2f2);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H2 df3' df4' df5' df6' dfc';df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df2';f3;f4;f5;f6;fc];   
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(12)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{12}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(13)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(13)>0.00000000001 & error2>0.000001)
    H3=eval(d2f3);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H3 df1' df2' df4' df5' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df3';f1;f2;f4;f5;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(13)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{13}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(14)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(14)>0.00000000001 & error2>0.000001)
    H3=eval(d2f3);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H3 df1' df4' df5' df6' dfc';df1 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df3';f1;f4;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(14)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{14}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(15)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(15)>0.00000000001 & error2>0.000001)
    H3=eval(d2f3);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H3 df1' df4' df5' df2' dfc';df1 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df2 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df3';f1;f4;f5;f2;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(15)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{15}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(16)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(16)>0.00000000001 & error2>0.000001)
    H3=eval(d2f3);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H3 df1' df4' df2' df6' dfc';df1 0 0 0 0 0;df4 0 0 0 0 0;df2 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df3';f1;f4;f2;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(16)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{16}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(17)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(17)>0.00000000001 & error2>0.000001)
    H3=eval(d2f3);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H3 df1' df3' df5' df6' dfc';df1 0 0 0 0 0;df2 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df3';f1;f2;f5;f6;fc];   
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(17)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{17}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(18)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(18)>0.00000000001 & error2>0.000001)
    H3=eval(d2f3);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H3 df2' df4' df5' df6' dfc';df2 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df3';f2;f4;f5;f6;fc];        
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(18)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{18}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(19)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(19)>0.00000000001 & error2>0.000001)
    H4=eval(d2f4);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H4 df1' df2' df3' df5' dfc';df1 0 0 0 0 0;df2 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df4';f1;f2;f3;f5;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(19)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{19}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(20)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(20)>0.00000000001 & error2>0.000001)
    H4=eval(d2f4);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H4 df1' df3' df5' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df4';f1;f3;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(20)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{20}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(21)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(21)>0.00000000001 & error2>0.000001)
    H4=eval(d2f4);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H4 df1' df3' df5' df2' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;df2 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df4';f1;f3;f5;f2;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(21)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{21}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(22)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(22)>0.00000000001 & error2>0.000001)
    H4=eval(d2f4);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H4 df1' df3' df2' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df2 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df4';f1;f3;f2;f6;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(22)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{22}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(23)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(23)>0.00000000001 & error2>0.000001)
    H4=eval(d2f4);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H4 df1' df3' df5' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df4';f1;f2;f5;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(23)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{23}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(24)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(24)>0.00000000001 & error2>0.000001)
    H4=eval(d2f4);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H4 df2' df3' df5' df6' dfc';df2 0 0 0 0 0;df3 0 0 0 0 0;df5 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];  
    S=-[df4';f2;f3;f5;f6;fc];         
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(24)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{24}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(25)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(25)>0.00000000001 & error2>0.000001)
    H5=eval(d2f5);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H5 df1' df2' df3' df4' dfc';df1 0 0 0 0 0;df2 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df5';f1;f2;f3;f4;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(25)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{25}=matrixA(K);
error(26)=1;
mk=[k1 k2 k3 k4 k5];
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(26)>0.00000000001 & error2>0.000001)
    H5=eval(d2f5);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H5 df1' df3' df4' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df5';f1;f3;f4;f6;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(26)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{26}=matrixA(K);
mk=[k1 k2 k3 k4 k5];
error(27)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(27)>0.00000000001 & error2>0.000001)
    H5=eval(d2f5);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H5 df1' df3' df4' df2' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df2 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df5';f1;f3;f4;f2;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(27)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{27}=matrixA(K);
error(28)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(28)>0.00000000001 & error2>0.000001)
    H5=eval(d2f5);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H5 df1' df3' df2' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df2 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df5';f1;f3;f2;f6;fc];
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(28)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{28}=matrixA(K);
error(29)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(29)>0.00000000001 & error2>0.000001)
    H5=eval(d2f5);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H5 df1' df3' df4' df6' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df5';f1;f2;f4;f6;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(29)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{29}=matrixA(K);
error(30)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(30)>0.00000000001 & error2>0.000001)
    H5=eval(d2f5);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H5 df2' df3' df4' df6' dfc';df2 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df6 0 0 0 0 0;dfc 0 0 0 0 0;];  
    S=-[df5';f2;f3;f4;f6;fc];             
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(30)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{30}=matrixA(K);
error(31)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(31)>0.00000000001 & error2>0.000001)
    H6=eval(d2f6);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H6 df2' df3' df4' df5' dfc';df2 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];    
    S=-[df6';f2;f3;f4;f5;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(31)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{31}=matrixA(K);
error(32)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(32)>0.00000000001 & error2>0.000001)
    H6=eval(d2f6);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H6 df1' df2' df3' df4' dfc';df1 0 0 0 0 0;df2 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df6';f1;f2;f3;f4;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(32)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{32}=matrixA(K);
error(33)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(33)>0.00000000001 & error2>0.000001)
    H6=eval(d2f6);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H6 df1' df3' df4' df5' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df6';f1;f3;f4;f5;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(33)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{33}=matrixA(K);
error(34)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(34)>0.00000000001 & error2>0.000001)
    H6=eval(d2f6);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H6 df1' df3' df4' df2' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df2 0 0 0 0 0;dfc 0 0 0 0 0;];
    S=-[df6';f1;f3;f4;f2;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(34)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{34}=matrixA(K);
error(35)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(35)>0.00000000001 & error2>0.000001)
    H6=eval(d2f6);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H6 df1' df3' df2' df5' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df2 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;]; 
    S=-[df6';f1;f3;f2;f5;fc];    
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(35)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{35}=matrixA(K);
error(36)=1;
n=1;
M=[];
S=[];
error2=100;
while (n<=itermax & error(36)>0.00000000001 & error2>0.000001)
    H6=eval(d2f6);
    f1=eval(f(1,1));
    f2=eval(f(1,2));
    f3=eval(f(1,3));
    f4=eval(f(1,4));
    f5=eval(f(1,5));
    f6=eval(f(1,6));
    df1=eval(df(:,1)');
    df2=eval(df(:,2)');
    df3=eval(df(:,3)');
    df4=eval(df(:,4)');
    df5=eval(df(:,5)');
    df6=eval(df(:,6)');
    M=[H6 df1' df3' df4' df5' dfc';df1 0 0 0 0 0;df3 0 0 0 0 0;df4 0 0 0 0 0;df5 0 0 0 0 0;dfc 0 0 0 0 0;];           
    S=-[df6';f1;f3;f4;f5;fc];             
    p=inv(M)*S;
    mk=mk+p(1:5)';
    k1=mk(1);k2=mk(2);k3=mk(3);k4=mk(4);k5=mk(5);
    error(36)=norm([f1 f2 f3 f4 f5 f6 fc]);
    error2=norm(p(1:5));
    n=n+1;
end
K=[k1 k2 k3;k2 k4 k5;k3 k5 1];
A{36}=matrixA(K);
for i=1:36
    if (sum(sum(A{i}))>0 & sum(sum(A{i}))<10^6)
        matriuA=A{i};
        erra=(trace(A{i}'*F1*A{i}*A{i}'*F1'*A{i}))^2-2*trace((A{i}'*F1*A{i}*A{i}'*F1'*A{i})^2);
        errb=(trace(A{i}'*F2*A{i}*A{i}'*F2'*A{i}))^2-2*trace((A{i}'*F2*A{i}*A{i}'*F2'*A{i})^2);
        errc=(trace(A{i}'*F3*A{i}*A{i}'*F3'*A{i}))^2-2*trace((A{i}'*F3*A{i}*A{i}'*F3'*A{i})^2);
        err(i)=norm([erra errb errc]);
    else
        err(i)=10^28;
    end
end

[val indexhg]=min(err);
Ahg=A{indexhg};
errorhf=err(indexhg);
    